@@ -21,6 +21,7 @@
 use chrono::{DateTime, Utc};
 use pgp::crypto::aead::AeadAlgorithm;
 use pgp::crypto::hash::HashAlgorithm;
+use pgp::crypto::public_key::PublicKeyAlgorithm;
 use pgp::crypto::sym::SymmetricKeyAlgorithm;
 use pgp::types::{CompressionAlgorithm, EcdhPublicParams, PublicParams};
 
@@ -91,11 +92,11 @@ const RSA_UNDER_2K_REJECT_AFTER: i64 = 1388534400;
 
 const RSA_UNDER_2K_CUTOFF_BIT_SIZE: usize = 2048;
 
-/// Cutoff time for DSA acceptance: February 3, 2023 12:00:00 AM (GMT)
+/// Cutoff time for validation and creation of DSA signatures: February 3, 2023 12:00:00 AM (GMT)
 /// See https://nvlpubs.nist.gov/nistpubs/FIPS/NIST.FIPS.186-5.pdf
 const DSA_REJECT_AFTER: i64 = 1675382400;
 
-/// Returns our policy about a `PublicParams` at a reference time.
+/// Returns our policy about the general acceptability of a `PublicParams` at a reference time.
 pub(crate) fn acceptable_pk_algorithm(pp: &PublicParams, reference: &DateTime<Utc>) -> bool {
     if let PublicParams::RSA { n, e: _ } = pp {
         let mut rsa_bits = n.len() * 8;
@@ -124,7 +125,8 @@ pub(crate) fn acceptable_pk_algorithm(pp: &PublicParams, reference: &DateTime<Ut
 
 /// Returns our policy about a `HashAlgorithm` at a reference time.
 ///
-/// Note that we reject SHA-1 at different dates, depending on whether it is used for data signatures or other types of signatures.
+/// Note that we reject SHA-1 at different dates, depending on whether it is used for data
+/// signatures or structural signatures.
 pub(crate) fn acceptable_hash_algorithm(
     hash_algo: &HashAlgorithm,
     reference: &DateTime<Utc>,
@@ -176,3 +178,16 @@ pub(crate) fn accept_for_encryption(pp: &PublicParams) -> bool {
         _ => true,
     }
 }
+
+/// Return our policy about acceptable public key mechanisms for signatures.
+///
+/// This policy applies validation of existing signatures based on their (claimed) creation time,
+/// and to issuing new signatures.
+pub(crate) fn accept_for_signatures(pk_alg: PublicKeyAlgorithm, reference: &DateTime<Utc>) -> bool {
+    if pk_alg == PublicKeyAlgorithm::DSA {
+        // Only allow DSA signatures until the cutoff date (03.02.2023)
+        reference.timestamp() <= DSA_REJECT_AFTER
+    } else {
+        true
+    }
+}
