@@ -2,7 +2,7 @@
 // SPDX-License-Identifier: MIT OR Apache-2.0
 
 use chrono::Duration;
-use pgp::types::PublicParams;
+use pgp::types::{EcdhPublicParams, PublicParams};
 
 /// Map expiration Duration to OpenPGP style seconds.
 ///
@@ -15,9 +15,8 @@ pub(crate) fn duration_to_seconds(d: Option<&Duration>) -> Option<u32> {
 pub(crate) fn algo_name(pp: &PublicParams) -> String {
     match pp {
         PublicParams::RSA { n, .. } => format!("RSA {}", n.len() * 8),
-        PublicParams::ECDH { curve, .. } | PublicParams::EdDSA { curve, .. } => {
-            curve.name().to_string()
-        }
+        PublicParams::ECDH(EcdhPublicParams::Known { curve, .. })
+        | PublicParams::EdDSALegacy { curve, .. } => curve.name().to_string(),
         PublicParams::ECDSA(_) => "ECDSA".to_string(),
         _ => "TODO".to_string(),
     }
